Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(231)

Unified Diff: chrome/browser/tab_contents/tab_contents.h

Issue 5906001: Makes linux honor instant_is_active when instant temporarily hides. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: true Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gtk/browser_window_gtk.cc ('k') | chrome/browser/tab_contents/tab_contents.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/tab_contents.h
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h
index 3ae7941ed04793e0b28b4b0e28216120695f1066..ddf8ae4a6c8d666fa6f0986eee4bdcf6be3b1c74 100644
--- a/chrome/browser/tab_contents/tab_contents.h
+++ b/chrome/browser/tab_contents/tab_contents.h
@@ -734,8 +734,8 @@ class TabContents : public PageNavigator,
int GetZoomPercent(bool* enable_increment, bool* enable_decrement);
// Shows a fade effect over this tab contents. Repeated calls will be ignored
- // until the fade is canceled.
- void FadeForInstant();
+ // until the fade is canceled. If |animate| is true the fade should animate.
+ void FadeForInstant(bool animate);
// Immediately removes the fade.
void CancelInstantFade();
« no previous file with comments | « chrome/browser/gtk/browser_window_gtk.cc ('k') | chrome/browser/tab_contents/tab_contents.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698